pub struct Last4Redactor;Expand description
Redact all but the last 4 characters.
Useful for tokens, card numbers, or other identifiers where seeing the last few characters helps with identification.
Always shows at least 4 asterisks to avoid leaking information about short values or value length.
use apollo_redaction::Redacted;
use apollo_redaction::strategy::Last4Redactor;
fn last4(input: &str) -> String {
Redacted::<_, Last4Redactor>::new(input).to_string()
}
assert_eq!(last4("1234567890"), "******7890");
assert_eq!(last4("abc"), "****");
assert_eq!(last4("4242424242424242"), "************4242");Trait Implementations
Sourceimpl Clone for Last4Redactor
impl Clone for Last4Redactor
Sourcefn clone(&self) -> Last4Redactor
fn clone(&self) -> Last4Redactor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for Last4Redactor
impl Default for Last4Redactor
Sourcefn default() -> Last4Redactor
fn default() -> Last4Redactor
Returns the “default value” for a type. Read more