pub struct Redacted<T, R = SimpleRedactor> { /* private fields */ }Expand description
A wrapper type for redacting values, so the actual values are not accidentally printed out.
A redacted value comes with a redaction strategy. The strategy provides the Display and
Debug implementations for the inner type.
To access the redacted value proper, you must use the Redacted::unredact method.
Implementations
Sourceimpl<T, R> Redacted<T, R>
impl<T, R> Redacted<T, R>
Sourcepub fn with_strategy(value: T, strategy: R) -> Self
pub fn with_strategy(value: T, strategy: R) -> Self
Create a new redacted value with a redaction strategy.