Redacted

Struct Redacted 

pub struct Redacted<T, R = SimpleRedactor> { /* private fields */ }
A wrapper type for redacting values, so the actual values are not accidentally printed out.

A redacted value comes with a redaction strategy. The strategy provides the Display and Debug implementations for the inner type.

To access the redacted value proper, you must use the Redacted::unredact method.

Implementations

Source

impl<T, R: Default> Redacted<T, R>

pub fn new(value: T) -> Self

Create a new redacted value with a Default redaction strategy.

use apollo_redaction::Redacted;
use apollo_redaction::strategy::SimpleRedactor;

let redacted = Redacted::<_, SimpleRedactor>::new("password for all the company's secrets");
Source

impl<T, R> Redacted<T, R>

pub fn with_strategy(value: T, strategy: R) -> Self

Create a new redacted value with a redaction strategy.

Source

impl<T, R> Redacted<T, R>

pub fn unredact(&self) -> &T

Access the underlying value.

pub fn unredact_mut(&mut self) -> &mut T

Access the underlying value.